# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['autoembedder']

package_data = \
{'': ['*']}

install_requires = \
['dask==2022.5.0',
 'einops==0.5.0',
 'numpy==1.23.4',
 'pandas==1.5.0',
 'pyarrow==7.0.0',
 'pytorch-ignite==0.4.10',
 'tensorboard==2.10.1',
 'torch==1.12.1',
 'torchinfo==1.7.1',
 'tqdm==4.64.1']

setup_kwargs = {
    'name': 'autoembedder',
    'version': '0.1',
    'description': 'PyTorch autoencoder with additional embeddings layer for categorical data.',
    'long_description': '# The Autoembedder\n[![docs](https://img.shields.io/badge/docs-mkdoks%20material-blue)](https://chrislemke.github.io/autoembedder/)\n[![license](https://img.shields.io/github/license/chrislemke/feature-reviser)](https://github.com/chrislemke/feature-reviser/blob/main/LICENSE)\n[![mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)\n[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)\n[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)\n## Introduction\nThe Autoembedder is an autoencoder with additional embedding layers for the categorical columns. Its usage is flexible, and hyperparameters like the number of layers can be easily adjusted and tuned. Although primarily designed for Panda\'s dataframes, it can be easily modified to support other data structures.\n\n## Let\'s get started\n`training.py` is where everything begins. The following arguments can / should be set:\n\n| Argument                           | Type  | Required | Default value    | Comment                                                                                                                                                                                  |\n| ---------------------------------- | ----- | -------- | ---------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |\n| batch_size                         | int   | False    | 32               |                                                                                                                                                                                          |\n| drop_last                          | int   | False    | 1                | True/False                                                                                                                                                                               |\n| pin_memory                         | int   | False    | 1                | True/False                                                                                                                                                                               |\n| num_workers                        | int   | False    | 0                | 0 means that the data will be loaded in the main process                                                                                                                                 |\n| use_mps                        | int   | False    | 0                | Set this to `1` if you want to use the [MPS Backend](https://pytorch.org/docs/master/notes/mps.html) for running on Mac using the M1 GPU. process                                                                                                                                 |\n| model_title                        | str   | False    | autoembedder_{datetime}.bin |                                                                                                                                                                                          |\n| model_save_path                    | str   | False    |                  |                                                                                                                                                                                          |\n| n_save_checkpoints                 | int   | False    |                  |                                                                                                                                                                                          |\n| lr                                 | float | False    | 0.001            |                                                                                                                                                                                          |\n| amsgrad                                 | int | False    | 0            | True/False\n| epochs                             | int   | True     |                  |\n| layer_bias                             | int   | False     |  1                | True/False|                                                                                                                                                                                          |\n| weight_decay                       | float | False    | 0                |                                                                                                                                                                                          |\n| l1_lambda                          | float | False    | 0                |                                                                                                                                                                                          |\n| xavier_init                        | int   | False    | 0                | True/False                                                                                                                                                                               |\n| tensorboard_log_path               | str   | False    |                  |                                                                                                                                                                                          |\n| train_input_path                   | str   | True     |                  |                                                                                                                                                                                          |\n| test_input_path                    | str   | True     |                  |                                                                                                                                                                                                                                                                                                                                                                                    |\n| activation_for_code_layer          | int   | False    | 0                | True/False, should the layer have an activation                                                                                                                                          |\n| activation_for_final_decoder_layer | int   | False    | 0                | True/False, should the final decoder layer have an activation                                                                                                                            |\n| hidden_layer_representation        | str   | True     |                  | Contains a string representation of a list of list of integers which represents the hidden layer structure. E.g.: `"[[64, 32], [32, 16], [16, 8]]"` activation                           |\n| cat_columns                        | str   | False    | "[]"             | Contains a string representation of a list of list of categorical columns (strings). The columns which use the same encoder should be together in a list. E.g.: `"[[\'a\', \'b\'], [\'c\']]"`. |\n\nSo, something like this would do it:\n\n```\n$ python3 training.py --epochs 20 \\\n--train_input_path "path/to/your/train_data" \\\n--test_input_path "path/to/your/test_data" \\\n--hidden_layer_representation "[[12, 6], [6, 3]]"\n```\n\n\n## Why additional embedding layers?\nThe additional embedding layers automatically embed all columns with the Pandas `category` data type. If categorical columns have another data type, they will not be embedded and will be handled like the continuous columns. Simply encoding the categorical values (e.g., with the usage of a label encoder) decreases the quality of the outcome.\n',
    'author': 'Christopher Lemke',
    'author_email': 'chris@syhbl.mozmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/chrislemke/autoembedder',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<3.11',
}


setup(**setup_kwargs)
